close all; clear all; format long;
c=299792458*1e3;

%resultFolder = '..\results\';
fileEnding = 'dragResultData.mat';
resultFolder = 'rawData\';
resonatorFile = 'd34_stp05_BHF_62_15um_850nm_pol1';
%resonatorFile = 'd34_plasma_15um_850nm_pol1_';
%resonatorFile = 'd34_ebl3h_143_15um_750nm_';

%% find all files to analyze and load power correction file
filesToAnalyze = dir([resultFolder resonatorFile '*' fileEnding]);

kappa1_1 = [];
kappa2_1 = [];
kappa1_2 = [];
kappa2_2 = [];
couplingEff = [];
tP1 = [];
tP2 = [];
wls = [];
sus = [];
off = [];
res = [];

%% loop through all files that are supposed to be analyzed
for i = 1:size(filesToAnalyze,1)
    disp( '-------------------------------------------------------------' );
    disp( ['Loading file: ' filesToAnalyze(i).name '...'] );
    load( [resultFolder filesToAnalyze(i).name] );
    
    off = [off offset];
    sus = [sus susceptibility];
    kappa1_1 = [kappa1_1 k1_1];
    kappa2_1 = [kappa2_1 k2_1];
    kappa1_2 = [kappa1_2 k1_2];
    kappa2_2 = [kappa2_2 k2_2];
    couplingEff = [couplingEff mean(couplingEfficiency)];
    tP1 = [tP1 thresholdPower1];
    tP2 = [tP2 thresholdPower2];
    wls = [wls params.wl];
    res = [res residual];

end

%% assume undercoupling and find intrinsic Q
k0s_1 = kappa1_1;
kEs_1 = kappa2_1;
k0s_1(kappa1_1 < kappa2_1) = kappa2_1(kappa1_1 < kappa2_1);
kEs_1(kappa1_1 < kappa2_1) = kappa1_1(kappa1_1 < kappa2_1);
k0s_2 = kappa1_2;
kEs_1 = kappa2_2;
k0s_2(kappa1_2 < kappa2_2) = kappa2_2(kappa1_2 < kappa2_2);
kEs_2(kappa1_2 < kappa2_2) = kappa1_2(kappa1_2 < kappa2_2);
k0s = mean( [k0s_1; k0s_2] );
kEs = mean( [kEs_1; kEs_2] );

%% some parameters
crit = res>0.8;

waveLengths = c./(1460:1:1570);
dwdT_cladded = 1e3*(0.000000018424750*(waveLengths)-1.029212944009243 );
dwdT_uncladded = 1e2*(0.000000158796103*(waveLengths)-4.365816437789750 );

% take values from COMSOL simulation
dTdP_cladded = 0.216;
dTdP_cladded_2 = 0.157;
dTdP_uncladded = 0.286;
dTdP_uncladded_2 = 0.006;

%% start nice plotting
fontSize=7;
fontSizeSmall=7;

figWidth = 4.5;
figHeight = 5.5;

dragFig = figure( 'Units', 'centimeters', 'PaperUnit','centimeters' );
set( dragFig, 'Position', [1 1 figWidth+3 figHeight+3]);
set( dragFig,'PaperSize',[figWidth+3 figHeight+3]);
set( dragFig,'PaperPosition',[0 0 figWidth+3 figHeight+3]);

dragAxes = subplot(2,1,1);
set( dragAxes, 'Units', 'centimeters' );
%set(idealityAxes, 'Position', [1.5 1.5 figWidth figHeight] );
set(dragAxes, 'box', 'on');
set(dragAxes,'fontsize',fontSize);
set(dragAxes, 'LineWidth', 1 );
set(dragAxes, 'XAxisLocation', 'top')
%title(idealityAxes, ['Ideality study of ' sampleID ' - mode family ' num2str(wantedModeFamily)] );
xlabel(dragAxes, '\bf wavelength (nm)','fontsize',fontSize );
ylabel(dragAxes, '\bf susceptibility (MHz/mW)','fontsize',fontSize );
xlim(dragAxes, [1460 1570]);
ylim(dragAxes, [0 600]);
hold( dragAxes );

qAxes = subplot(2,1,2);
set( qAxes, 'Units', 'centimeters' );
%set(idealityAxes, 'Position', [1.5 1.5 figWidth figHeight] );
set(qAxes, 'box', 'on');
set(qAxes,'fontsize',fontSize);
set(qAxes, 'LineWidth', 1 );
%title(idealityAxes, ['Ideality study of ' sampleID ' - mode family ' num2str(wantedModeFamily)] );
xlabel(qAxes, '\bf wavelength (nm)','fontsize',fontSize );
ylabel(qAxes, '\bf \kappa_0/2\pi (MHz)','fontsize',fontSize );
xlim(qAxes, [1460 1570]);
ylim(qAxes, [0 120]);
hold( qAxes );

% do the actual plotting
scatter( dragAxes, wls(crit), sus(crit), 'x' );
plot( dragAxes, wls(crit), smooth( sus(crit), 5 ) );
%plot( dragAxes, waveLengths, dwdT_cladded*dTdP_cladded );
%plot( dragAxes, [1545 1545], [0 600]);
%plot( dragAxes, [1550 1550], [0 600]);
%plot( dragAxes, [1508 1508], [0 600]);
%plot( dragAxes, [1513 1513], [0 600]);
%plot( dragAxes, [1493 1493], [0 600]);
%plot( dragAxes, [1496 1496], [0 600]);
%modal crossing 1545-1550, 1508-1513, 1493-1496

plot( dragAxes, [1530 1530], [0 600]);
plot( dragAxes, [1517 1517], [0 600]);
plot( dragAxes, [1501 1501], [0 600]);
plot( dragAxes, c./waveLengths, dwdT_uncladded*dTdP_uncladded );
%plot( dragAxes, c./waveLengths, dwdT_uncladded*dTdP_uncladded_2 );
%plot( dragAxes, c./waveLengths, dwdT_cladded*dTdP_cladded );
%plot( dragAxes, c./waveLengths, dwdT_cladded*dTdP_cladded_2 );


scatter( qAxes, wls(crit), k0s(crit), 'x' );
plot( qAxes, wls(crit), smooth( k0s(crit), 5 ) );
% dwdT_cladded = 1e3*(0.000000018424750*(c./wls(crit))-1.029212944009243 );
% plot( qAxes, wls(crit), smooth( k0s(crit), 5 ).*smooth( sus(crit), 5 )/(dwdT_cladded'*dTdP_cladded) );
% plot( qAxes, wls(crit), smooth( k0s(crit), 5 ).*smooth( sus(crit), 5 )/(dwdT_cladded'*dTdP_cladded_2) );
% disp( ['Mean kabs: ' num2str(mean( (smooth( k0s(crit), 5 ).*smooth( sus(crit), 5 )/(dwdT_cladded'*dTdP_cladded))) )] );

dwdT_uncladded = 1e2*(0.000000158796103*(c./wls(crit))-4.365816437789750 );
plot( qAxes, wls(crit), smooth( k0s(crit), 5 ).*smooth( sus(crit), 5 )/(dwdT_uncladded'*dTdP_uncladded) );
disp( ['Mean kabs: ' num2str(mean( (smooth( k0s(crit), 5 ).*smooth( sus(crit), 5 )/(dwdT_uncladded'*dTdP_uncladded))) )] );

% mode crossings
%plot( qAxes, [1545 1545], [0 600]);
%plot( qAxes, [1550 1550], [0 600]);
%plot( qAxes, [1508 1508], [0 600]);
%plot( qAxes, [1513 1513], [0 600]);
%plot( qAxes, [1493 1493], [0 600]);
%plot( qAxes, [1496 1496], [0 600]);

% absorption lines
plot( qAxes, [1530 1530], [0 600]);
plot( qAxes, [1517 1517], [0 600]);
plot( qAxes, [1501 1501], [0 600]);

print(dragFig, 'spectroUnclad2.pdf','-dpdf');
