close all; clear all; format long;
c=299792458*1e3;

fileEnding = 'dragResultData.mat';
resultFolder = 'rawData\';

resonatorFile = 'd34_ebl3h_143_15um_750nm_';
filesToAnalyze = dir([resultFolder resonatorFile '*' fileEnding]);
[wls_ebl3h, sus_ebl3h, res_ebl3h, k0s_ebl3h] = summarizeValues( resultFolder, filesToAnalyze );

resonatorFile = 'd34_plasma_15um_850nm_pol1_';
filesToAnalyze = dir([resultFolder resonatorFile '*' fileEnding]);
[wls_noC, sus_noC, res_noC, k0s_noC] = summarizeValues( resultFolder, filesToAnalyze );

resonatorFile = 'd34_stp05_BHF_62_15um_850nm_';
filesToAnalyze = dir([resultFolder resonatorFile '*' fileEnding]);
[wls_bhf, sus_bhf, res_bhf, k0s_bhf] = summarizeValues( resultFolder, filesToAnalyze );


%% do nice plotting
fontSize=7;
fontSizeSmall=7;

figWidth = 4.5;
figHeight = 5.5;

dragFig = figure( 'Units', 'centimeters', 'PaperUnit','centimeters' );
set( dragFig, 'Position', [1 1 figWidth+3 figHeight+3]);
set( dragFig,'PaperSize',[figWidth+3 figHeight+3]);
set( dragFig,'PaperPosition',[0 0 figWidth+3 figHeight+3]);

dragAxes = subplot(2,1,1);
set( dragAxes, 'Units', 'centimeters' );
%set(idealityAxes, 'Position', [1.5 1.5 figWidth figHeight] );
set(dragAxes, 'box', 'on');
set(dragAxes,'fontsize',fontSize);
set(dragAxes, 'LineWidth', 1 );
set(dragAxes, 'XAxisLocation', 'top')
%title(idealityAxes, ['Ideality study of ' sampleID ' - mode family ' num2str(wantedModeFamily)] );
xlabel(dragAxes, '\bf wavelength (nm)','fontsize',fontSize );
ylabel(dragAxes, '\bf susceptibility (MHz/mW)','fontsize',fontSize );
xlim(dragAxes, [1460 1570]);
ylim(dragAxes, [0 600]);
hold( dragAxes );

qAxes = subplot(2,1,2);
set( qAxes, 'Units', 'centimeters' );
%set(idealityAxes, 'Position', [1.5 1.5 figWidth figHeight] );
set(qAxes, 'box', 'on');
set(qAxes,'fontsize',fontSize);
set(qAxes, 'LineWidth', 1 );
%title(idealityAxes, ['Ideality study of ' sampleID ' - mode family ' num2str(wantedModeFamily)] );
xlabel(qAxes, '\bf wavelength (nm)','fontsize',fontSize );
ylabel(qAxes, '\bf \kappa_0/2\pi (MHz)','fontsize',fontSize );
xlim(qAxes, [1460 1570]);
ylim(qAxes, [30 120]);
hold( qAxes );

% plot the susceptibility values
%tmp = smooth( sus_ebl3h(res_ebl3h>0.85), 10 )
plot( dragAxes, wls_ebl3h(res_ebl3h>0.9), smooth( sus_ebl3h(res_ebl3h>0.9), 10 ) );
plot( dragAxes, wls_noC(res_noC>0.9), smooth( sus_noC(res_noC>0.9), 10 ) );
plot( dragAxes, wls_bhf(res_bhf>0.9), smooth( sus_bhf(res_bhf>0.9), 10 ) );

plot( dragAxes, [1530 1530], [0 600]);
plot( dragAxes, [1517 1517], [0 600]);
plot( dragAxes, [1501 1501], [0 600]);
%plot( dragAxes, waveLengths, dwdT_uncladded*dTdP_uncladded );

% plot the Q values
plot( qAxes, wls_ebl3h(res_ebl3h>0.9), smooth( k0s_ebl3h(res_ebl3h>0.9), 10 ) );
plot( qAxes, wls_noC(res_noC>0.9), smooth( k0s_noC(res_noC>0.9), 10 ) );
plot( qAxes, wls_bhf(res_bhf>0.9), smooth( k0s_bhf(res_bhf>0.9), 10 ) );

xq = 1470:1:1550;
%vq1 = interp1(wls_ebl3h(res_ebl3h>0.9), smooth( k0s_ebl3h(res_ebl3h>0.9), 10 ),xq);
%vq2 = interp1(wls_noC(res_noC>0.9), smooth( k0s_noC(res_noC>0.9), 10 ),xq);
%vq3 = interp1(wls_bhf(res_bhf>0.9), smooth( k0s_bhf(res_bhf>0.9), 10 ),xq);

vq1 = interp1(wls_ebl3h(res_ebl3h>0.9), smooth( sus_ebl3h(res_ebl3h>0.9), 10 ),xq);
vq2 = interp1(wls_noC(res_noC>0.9), smooth( sus_noC(res_noC>0.9), 10 ),xq);
vq3 = interp1(wls_bhf(res_bhf>0.9), smooth( sus_bhf(res_bhf>0.9), 10 ),xq);

plot( qAxes, xq, vq1/vq2 );

plot( qAxes, [1530 1530], [0 600]);
plot( qAxes, [1517 1517], [0 600]);
plot( qAxes, [1501 1501], [0 600]);

print(dragFig, 'spectroComparison.pdf','-dpdf');
