function maxProb = analyseDistribution( file, censor )

wantedModeFamily = 1;
higherFreq = 205e6;%1500nm
lowerFreq = 120e6;

% load resonance data sets
disp( '-------------------------------------------------------------' );
disp( ['Loading file: ' file '...'] );
load( file );

% HACK: sort out weird stuff
for tt = 1:length(resonanceData)
    if ~isempty( resonanceData(tt).omega0Abs ) && isempty( resonanceData(tt).kappa0 )
        resonanceData(tt).omega0Abs = [];
        modeFamily(tt) = -1;
    end
end

modeFamily( modeFamily == -1 ) = [];

gof = [resonanceData.gof];
k0 = [resonanceData.kappa0];
kEx = [resonanceData.kappaEx];
kCR = [resonanceData.kappaCR];
kCI = [resonanceData.kappaCI];
resFreq = [resonanceData.omega0Abs];

% formulate criterion to sort out values
critSplit = kCI*1.33;
criterion = (gof > 0.97 & modeFamily == wantedModeFamily & ((~isnan(kCR)& critSplit > k0) | isnan(kCR)) );

% adapt to coupling model for ambiguity fitting
tmpk0 = k0;
tmpkEx = kEx;
k0( isnan( kCR ) & tmpk0<tmpkEx ) = tmpkEx( isnan( kCR ) & tmpk0<tmpkEx );
kEx( isnan( kCR ) & tmpk0<tmpkEx ) = tmpk0( isnan( kCR ) & tmpk0<tmpkEx );
kappa0s = k0( criterion );

% fit the distribution and extract max prob
if length( kappa0s ) > 15
    % censore linewidth below 30MHz
    %pd = fitdist( kappa0s', 'GeneralizedExtremeValue' );
    pd = fitdist( abs(kappa0s)', 'Burr', 'Censoring', (kappa0s<censor) );
    xVs = 10:0.1:5e3;
    [~,i] = max( pdf( pd, xVs ) );
    maxProb = xVs(i);
    
%    figure;
%    counts = hist( kappa0s, 25:5:120 );
%    xVs = 25:120;
%    yVs = pdf( pd, xVs );
%    bar( 25:5:120,counts );
%    line( xVs, yVs*(max(counts)/max(yVs)) );
%    disp( maxProb );
else
    criterion = (gof > 0.93 & modeFamily == wantedModeFamily & resFreq > lowerFreq & resFreq < higherFreq  );
    kappa0s = k0( criterion );
    maxProb = mean( kappa0s );
end

end